Installation
=============

It is recommended to use virtual environments for your projects to avoid potential conflicts with other packages. You can use either `uv` (recommended method) `venv` or `conda`. If you don't know how to set up a virtual environment, check out these quick guides:

1. `uv <uv_env_setup.html>`_  
2. `conda <conda_env_setup.html>`_

If you already have a virtual environment set up, you can proceed to install HySOM using pip or uv:

Using pip
----------
.. code-block:: bash

    pip install hysom  


Using uv
---------
.. code-block:: bash

    uv add hysom 
